# PyLambertW

This is a Python implementation for the R Package [LambertW](https://cran.r-project.org/web/packages/LambertW/index.html),
where you can find the source code [here](https://github.com/gmgeorg/LambertW).
